# Mime Utils

An package containing misc helper libraries for projects

* oauth2user - Support user interaction when logging inn with Oauth2

## Installation

Run the following to install:

```python
pip install mime-utils
```

## Usage

```python
from oauth2user import Oauth2User

TODO: Fill out here
```

# Developing Mime Utils

To install Mime Utils, along with the tools you need to develop and run tests, run the following in your virtualenv:

```bash
$ pip install -e .[dev]
```

